<?php

declare(strict_types=1);
namespace Drupal\translation_bliss\SourceLanguage;

use Drupal\Core\Language\LanguageInterface;
use Drupal\Core\StringTranslation\TranslationInterface;
use Drupal\Core\StringTranslation\Translator\TranslatorInterface;
use Symfony\Component\DependencyInjection\Attribute\Autowire;

/**
 * Get source language aware TranslationService.
 *
 * @api
 */
final class SourceLanguageTranslationServiceFactory implements SourceLanguageTranslationServiceFactoryInterface {

  /**
   * @internal
   */
  public function __construct(
    #[Autowire(service: TranslationInterface::class)]
    protected TranslationInterface & TranslatorInterface $translationManager,
  ) {}

  /**
   * Convenience constructor for SourceLanguageTranslationServiceFactory.
   *
   * @api
   */
  public static function create(): self {
    return \Drupal::service(self::class);
  }

  /**
   * @api
   */
  public function forSourceLangcode(string $sourceLangcode): TranslationInterface & TranslatorInterface {
    if ($sourceLangcode && $sourceLangcode !== 'en' && $sourceLangcode !== LanguageInterface::LANGCODE_SYSTEM) {
      return new SourceLanguageTranslationManagerDecorator($sourceLangcode, $this->translationManager);
    }
    else {
      return $this->translationManager;
    }
  }

}
