<?php

declare(strict_types=1);
namespace Drupal\Tests\translation_bliss\Kernel;

use Drupal\Core\StringTranslation\TranslatableMarkup;
use Drupal\Core\StringTranslation\TranslationInterface;
use Drupal\Core\StringTranslation\Translator\TranslatorInterface;
use Drupal\KernelTests\KernelTestBase;
use Drupal\translation_bliss\SourceLanguage\SourceLanguageTranslationServiceFactoryInterface;

final class SourceLanguageTest extends KernelTestBase {

  protected static $modules = [
    'translation_bliss',
    'locale',
  ];

  /**
   * @dataProvider provideSourceLanguage
   */
  public function testSourceLanguage(string $langcode, string $context, string $expectedContext): void {
    $factory = \Drupal::service(SourceLanguageTranslationServiceFactoryInterface::class);
    assert($factory instanceof SourceLanguageTranslationServiceFactoryInterface);
    $translator = $factory->forSourceLangcode($langcode);
    assert($translator instanceof TranslatorInterface);
    assert($translator instanceof TranslationInterface);

    $markup = $translator->translate(
      'Some @test',
      ['@text' => 'Text'],
      ['some_option' => 123] + ($context ? ['context' => $context] : [])
    );
    assert($markup instanceof TranslatableMarkup);

    $expected = new TranslatableMarkup(
      'Some @test',
      ['@text' => 'Text'],
      ['some_option' => 123] + ($expectedContext ? ['context' => $expectedContext] : [])
    );
    $this->assertEquals($expected, $markup);
  }

  public static function provideSourceLanguage() {
    yield ['en', '' , ''];
    yield ['en', 'myContext' , 'myContext'];
    yield ['de', '' , '[srclang=de]'];
    yield ['de', 'myContext' , '[srclang=de]myContext'];
  }

}
